Colour Temperature
==================

Correlated Colour Temperature
-----------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    uv_to_CCT
    UV_TO_CCT_METHODS
    CCT_to_uv
    CCT_TO_UV_METHODS
    xy_to_CCT
    XY_TO_CCT_METHODS
    CCT_to_xy
    CCT_TO_XY_METHODS

Robertson (1968)
~~~~~~~~~~~~~~~~

``colour.temperature``

.. currentmodule:: colour.temperature

.. autosummary::
    :toctree: generated/

    mired_to_CCT
    CCT_to_mired
    uv_to_CCT_Robertson1968
    CCT_to_uv_Robertson1968

Krystek (1985)
~~~~~~~~~~~~~~

``colour.temperature``

.. currentmodule:: colour.temperature

.. autosummary::
    :toctree: generated/

    uv_to_CCT_Krystek1985
    CCT_to_uv_Krystek1985

Ohno (2013)
~~~~~~~~~~~

``colour.temperature``

.. currentmodule:: colour.temperature

.. autosummary::
    :toctree: generated/

    uv_to_CCT_Ohno2013
    CCT_to_uv_Ohno2013
    XYZ_to_CCT_Ohno2013
    CCT_to_XYZ_Ohno2013

Planck (1900)
~~~~~~~~~~~~~

``colour.temperature``

.. currentmodule:: colour.temperature

.. autosummary::
    :toctree: generated/

    uv_to_CCT_Planck1900
    CCT_to_uv_Planck1900

McCamy (1992)
~~~~~~~~~~~~~

``colour.temperature``

.. currentmodule:: colour.temperature

.. autosummary::
    :toctree: generated/

    xy_to_CCT_McCamy1992
    CCT_to_xy_McCamy1992

Hernandez-Andres, Lee and Romero (1999)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

``colour.temperature``

.. currentmodule:: colour.temperature

.. autosummary::
    :toctree: generated/

    xy_to_CCT_Hernandez1999
    CCT_to_xy_Hernandez1999

Kang, Moon, Hong, Lee, Cho and Kim (2002)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

``colour.temperature``

.. currentmodule:: colour.temperature

.. autosummary::
    :toctree: generated/

    xy_to_CCT_Kang2002
    CCT_to_xy_Kang2002

CIE Illuminant D Series
~~~~~~~~~~~~~~~~~~~~~~~

``colour.temperature``

.. currentmodule:: colour.temperature

.. autosummary::
    :toctree: generated/

    xy_to_CCT_CIE_D
    CCT_to_xy_CIE_D
